# Copyright (C) 1998-2003 by the Free Software Foundation, Inc.
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
#
# Author: Bernhard Reiter <bernhard@gnu.org>

"""Standard Mailman generator object.

A subclass of email.Generator which only folds long headers
in the top object level. 
This is needed because Mailman should leave the reveiced message parts alone.
Otherwise is might change subparts over which a signature was calculated,
breaking it while doing so.
"""

import email
import email.Generator

try:
    True, False
except NameError:
    True = 1
    False = 0


class Generator(email.Generator.Generator):
    """Generates output from a Message object tree, keeping signatures.
    
    Using the a trick from Mailman/Handlers/Scrubber.py (revs 2.0-2.15):

    Most other Generator will be created not setting the foldheader flag,
    as we do not overwrite clone(). The original clone() does not
    set foldheaders.

    So you need to set foldheaders if you want the toplevel to fold headers.
    """
    def __init__(self, outfp, mangle_from_=True,
                 maxheaderlen=78, foldheaders=False):
        email.Generator.Generator.__init__(self, outfp, mangle_from_=False)
        self.__foldheaders = foldheaders

    def _write_headers(self, msg):
        if self.__foldheaders:
            email.Generator.Generator._write_headers(self, msg)
        else:
            # the following is 
            # unrolled from email.Generator.Generator._write_headers()
            for h, v in msg.items():
            	print >> self._fp, '%s:' % h,
                print >> self._fp, v
            print >> self._fp

